@@ -9,24 +9,39 @@
 */
 
 #include "kbookmark.h"
-#include <QStack>
-#include <QCoreApplication>
-#include <QMimeDatabase>
 #include "kbookmarks_debug.h"
-#include <KStringHandler>
-#include <kurlmimedata.h>
 #include <kbookmarkmanager.h>
 
+#include <KStringHandler>
+#include <kurlmimedata.h>
+
+#include <QCoreApplication>
+#include <QMimeDatabase>
+#include <QStack>
 #include <QDateTime>
 #include <QMimeData>
 
-namespace {
-namespace Strings {
-QString metaDataKDEOwner() { return QStringLiteral("http://www.kde.org"); }
-QString metaDataFreedesktopOwner() { return QStringLiteral("http://freedesktop.org"); }
-QString metaDataMimeOwner() { return QStringLiteral("http://www.freedesktop.org/standards/shared-mime-info"); }
+namespace
+{
+namespace Strings
+{
+QString metaDataKDEOwner()
+{
+    return QStringLiteral("http://www.kde.org");
+}
+QString metaDataFreedesktopOwner()
+{
+    return QStringLiteral("http://freedesktop.org");
+}
+QString metaDataMimeOwner()
+{
+    return QStringLiteral("http://www.freedesktop.org/standards/shared-mime-info");
+}
 
-QString xbelMimeType() { return QStringLiteral("application/x-xbel"); }
+QString xbelMimeType()
+{
+    return QStringLiteral("application/x-xbel");
+}
 }
 }
 
@@ -80,7 +95,7 @@ static QDomNode findMetadata(const QString &forOwner, QDomNode &parent, bool cre
         metadataElement.setAttribute(QStringLiteral("owner"), forOwner);
 
     } else if (!metadataElement.isNull() && forOwnerIsKDE) {
-        // i'm not sure if this is good, we shouln't take over foreign metatdata
+        // i'm not sure if this is good, we shouldn't take over foreign metadata
         metadataElement.setAttribute(QStringLiteral("owner"), Strings::metaDataKDEOwner());
     }
     return metadataElement;
@@ -133,8 +148,7 @@ QDomElement KBookmarkGroup::nextKnownTag(const QDomElement &start, bool goNext)
 {
     for (QDomElement elem = start; !elem.isNull();) {
         QString tag = elem.tagName();
-        if (tag == QLatin1String("folder") || tag == QLatin1String("bookmark")
-                || tag == QLatin1String("separator")) {
+        if (tag == QLatin1String("folder") || tag == QLatin1String("bookmark") || tag == QLatin1String("separator")) {
             return elem;
         }
         if (goNext) {
@@ -158,7 +172,6 @@ KBookmarkGroup KBookmarkGroup::createNewFolder(const QString &text)
     groupElem.appendChild(textElem);
     textElem.appendChild(doc.createTextNode(text));
     return KBookmarkGroup(groupElem);
-
 }
 
 KBookmark KBookmarkGroup::createNewSeparator()
@@ -217,7 +230,7 @@ KBookmark KBookmarkGroup::addBookmark(const QString &text, const QUrl &url, cons
     elem.appendChild(textElem);
     textElem.appendChild(doc.createTextNode(text));
 
-    KBookmark newBookmark =  addBookmark(KBookmark(elem));
+    KBookmark newBookmark = addBookmark(KBookmark(elem));
 
     // as icons are moved to metadata, we have to use the KBookmark API for this
     newBookmark.setIcon(icon);
@@ -239,8 +252,7 @@ QDomElement KBookmarkGroup::findToolbar() const
     if (element.attribute(QStringLiteral("toolbar")) == QLatin1String("yes")) {
         return element;
     }
-    for (QDomElement e = element.firstChildElement(QStringLiteral("folder")); !e.isNull();
-         e = e.nextSiblingElement(QStringLiteral("folder")) ) {
+    for (QDomElement e = element.firstChildElement(QStringLiteral("folder")); !e.isNull(); e = e.nextSiblingElement(QStringLiteral("folder"))) {
         QDomElement result = KBookmarkGroup(e).findToolbar();
         if (!result.isNull()) {
             return result;
@@ -267,15 +279,16 @@ KBookmark::KBookmark()
 {
 }
 
-KBookmark::KBookmark(const QDomElement &elem) : element(elem)
+KBookmark::KBookmark(const QDomElement &elem)
+    : element(elem)
 {
 }
 
 bool KBookmark::isGroup() const
 {
     QString tag = element.tagName();
-    return (tag == QLatin1String("folder")
-            || tag == QLatin1String("xbel"));  // don't forget the toplevel group
+    return tag == QLatin1String("folder") //
+        || tag == QLatin1String("xbel"); // don't forget the toplevel group
 }
 
 bool KBookmark::isSeparator() const
@@ -444,7 +457,7 @@ bool KBookmark::showInToolbar() const
         const_cast<QDomElement *>(&element)->removeAttribute(QStringLiteral("showintoolbar"));
         const_cast<KBookmark *>(this)->setShowInToolbar(show);
     }
-    return  metaDataItem(QStringLiteral("showintoolbar")) == QLatin1String("yes");
+    return metaDataItem(QStringLiteral("showintoolbar")) == QLatin1String("yes");
 }
 
 void KBookmark::setShowInToolbar(bool show)
@@ -466,7 +479,7 @@ KBookmarkGroup KBookmark::toGroup() const
 QString KBookmark::address() const
 {
     if (element.tagName() == QLatin1String("xbel")) {
-        return QLatin1String("");    // not QString() !
+        return QLatin1String(""); // not QString() !
     } else {
         // Use keditbookmarks's DEBUG_ADDRESSES flag to debug this code :)
         if (element.parentNode().isNull()) {
@@ -534,7 +547,7 @@ void KBookmark::updateAccessMetadata()
     setMetaDataItem(QStringLiteral("time_added"), QString::number(timet), DontOverwriteMetaData);
     setMetaDataItem(QStringLiteral("time_visited"), QString::number(timet));
 
-    QString countStr = metaDataItem(QStringLiteral("visit_count"));   // TODO use spec'ed name
+    QString countStr = metaDataItem(QStringLiteral("visit_count")); // TODO use spec'ed name
     bool ok;
     int currentCount = countStr.toInt(&ok);
     if (!ok) {
@@ -553,21 +566,22 @@ QString KBookmark::parentAddress(const QString &address)
 
 uint KBookmark::positionInParent(const QString &address)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    return QStringView(address).mid(address.lastIndexOf(QLatin1Char('/')) + 1).toInt();
+#else
     return address.midRef(address.lastIndexOf(QLatin1Char('/')) + 1).toInt();
+#endif
 }
 
 QString KBookmark::previousAddress(const QString &address)
 {
     uint pp = positionInParent(address);
-    return pp > 0
-           ? parentAddress(address) + QLatin1Char('/') + QString::number(pp - 1)
-           : QString();
+    return pp > 0 ? parentAddress(address) + QLatin1Char('/') + QString::number(pp - 1) : QString();
 }
 
 QString KBookmark::nextAddress(const QString &address)
 {
-    return parentAddress(address) + QLatin1Char('/') +
-           QString::number(positionInParent(address) + 1);
+    return parentAddress(address) + QLatin1Char('/') + QString::number(positionInParent(address) + 1);
 }
 
 QDomNode KBookmark::metaData(const QString &owner, bool create) const
@@ -659,7 +673,8 @@ void KBookmark::populateMimeData(QMimeData *mimeData) const
     bookmarkList.populateMimeData(mimeData);
 }
 
-KBookmark::List::List() : QList<KBookmark>()
+KBookmark::List::List()
+    : QList<KBookmark>()
 {
 }
 
@@ -710,8 +725,7 @@ KBookmark::List KBookmark::List::fromMimeData(const QMimeData *mimeData, QDomDoc
     bookmarks.reserve(urls.size());
     for (int i = 0; i < urls.size(); ++i) {
         const QUrl url = urls.at(i);
-        bookmarks.append(KBookmark::standaloneBookmark(url.toDisplayString(), url, QString()/*TODO icon*/));
+        bookmarks.append(KBookmark::standaloneBookmark(url.toDisplayString(), url, QString() /*TODO icon*/));
     }
     return bookmarks;
 }
-
