@@ -13,17 +13,26 @@
 
 #include <kbookmark.h>
 
+/**
+ * A class for exporting bookmarks
+ */
 class KBOOKMARKS_EXPORT KBookmarkExporterBase
 {
 public:
     KBookmarkExporterBase(KBookmarkManager *mgr, const QString &fileName)
-        : m_fileName(fileName), m_pManager(mgr)
-    {}
-    virtual ~KBookmarkExporterBase() {}
+        : m_fileName(fileName)
+        , m_pManager(mgr)
+    {
+    }
+    virtual ~KBookmarkExporterBase()
+    {
+    }
     virtual void write(const KBookmarkGroup &) = 0;
+
 protected:
     QString m_fileName;
     KBookmarkManager *m_pManager;
+
 private:
     class KBookmarkExporterBasePrivate *d;
 };
